Module: Google::Apis::GmailpostmastertoolsV2

Defined in:
lib/google/apis/gmailpostmastertools_v2.rb,
lib/google/apis/gmailpostmastertools_v2/classes.rb,
lib/google/apis/gmailpostmastertools_v2/service.rb,
lib/google/apis/gmailpostmastertools_v2/gem_version.rb,
lib/google/apis/gmailpostmastertools_v2/representations.rb

Overview

Gmail Postmaster Tools API

The Postmaster Tools API is a RESTful API that provides programmatic access to email traffic metrics (like spam reports, delivery errors etc) otherwise available through the Gmail Postmaster Tools UI currently.

Defined Under Namespace

Classes: BaseMetric, BatchQueryDomainStatsRequest, BatchQueryDomainStatsResponse, BatchQueryDomainStatsResult, ComplianceRowData, ComplianceStatus, Date, DateList, DateRange, DateRanges, Domain, DomainComplianceData, DomainComplianceStatus, DomainStat, HonorUnsubscribeVerdict, ListDomainsResponse, MetricDefinition, OneClickUnsubscribeVerdict, PostmasterToolsService, QueryDomainStatsRequest, QueryDomainStatsResponse, StatisticValue, Status, StringList, TimeQuery

Constant Summary collapse

GEM_VERSION =

Version of the google-apis-gmailpostmastertools_v2 gem

"0.2.0"
GENERATOR_VERSION =

Version of the code generator used to generate this client

"0.19.0"
REVISION =

Revision of the discovery document this client was generated from

"20260512"
VERSION =

Version of the Gmail Postmaster Tools API this client connects to. This is NOT the gem version.

'V2'
AUTH_POSTMASTER =

Get email traffic metrics, manage domains, and manage domain users for the domains you have registered with Postmaster Tools

'https://www.googleapis.com/auth/postmaster'
AUTH_POSTMASTER_DOMAIN =

View and manage the domains you have registered with Postmaster Tools

'https://www.googleapis.com/auth/postmaster.domain'
AUTH_POSTMASTER_TRAFFIC_READONLY =

Get email traffic metrics for the domains you have registered with Postmaster Tools

'https://www.googleapis.com/auth/postmaster.traffic.readonly'