Class: Google::Apis::GmailpostmastertoolsV2::BatchQueryDomainStatsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gmailpostmastertools_v2/classes.rb,
lib/google/apis/gmailpostmastertools_v2/representations.rb,
lib/google/apis/gmailpostmastertools_v2/representations.rb

Overview

Response message for BatchQueryDomainStats.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BatchQueryDomainStatsResponse

Returns a new instance of BatchQueryDomainStatsResponse.



75
76
77
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 75

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resultsArray<Google::Apis::GmailpostmastertoolsV2::BatchQueryDomainStatsResult>

A list of responses, one for each query in the BatchQueryDomainStatsRequest. The order of responses will correspond to the order of requests. Corresponds to the JSON property results



73
74
75
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 73

def results
  @results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



80
81
82
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 80

def update!(**args)
  @results = args[:results] if args.key?(:results)
end