Class: Google::Apis::GmailpostmastertoolsV2::DateRange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gmailpostmastertools_v2/classes.rb,
lib/google/apis/gmailpostmastertools_v2/representations.rb,
lib/google/apis/gmailpostmastertools_v2/representations.rb

Overview

A single date range defined by a start and end date.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DateRange

Returns a new instance of DateRange.



247
248
249
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 247

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#endGoogle::Apis::GmailpostmastertoolsV2::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property end



233
234
235
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 233

def end
  @end
end

#startGoogle::Apis::GmailpostmastertoolsV2::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property start



245
246
247
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 245

def start
  @start
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



252
253
254
255
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 252

def update!(**args)
  @end = args[:end] if args.key?(:end)
  @start = args[:start] if args.key?(:start)
end