Class: Google::Apis::GmailpostmastertoolsV2::Empty

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gmailpostmastertools_v2/classes.rb,
lib/google/apis/gmailpostmastertools_v2/representations.rb,
lib/google/apis/gmailpostmastertools_v2/representations.rb

Overview

A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs. A typical example is to use it as the request or the response type of an API method. For instance: service Foo rpc Bar(google. protobuf.Empty) returns (google.protobuf.Empty);

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Empty

Returns a new instance of Empty.



564
565
566
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 564

def initialize(**args)
   update!(**args)
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



569
570
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 569

def update!(**args)
end