Class: Google::Apis::GmailpostmastertoolsV2::ListDomainsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gmailpostmastertools_v2/classes.rb,
lib/google/apis/gmailpostmastertools_v2/representations.rb,
lib/google/apis/gmailpostmastertools_v2/representations.rb

Overview

Response message for ListDomains.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListDomainsResponse

Returns a new instance of ListDomainsResponse.



615
616
617
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 615

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#domainsArray<Google::Apis::GmailpostmastertoolsV2::Domain>

The domains that have been registered by the user. Corresponds to the JSON property domains



607
608
609
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 607

def domains
  @domains
end

#next_page_tokenString

Token to retrieve the next page of results, or empty if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


613
614
615
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 613

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



620
621
622
623
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 620

def update!(**args)
  @domains = args[:domains] if args.key?(:domains)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end