Class: Google::Apis::GmailpostmastertoolsV2::PostmasterToolsService

Inherits:
Core::BaseService
  • Object
show all
Defined in:
lib/google/apis/gmailpostmastertools_v2/service.rb

Overview

Gmail Postmaster Tools API

The Postmaster Tools API is a RESTful API that provides programmatic access to email traffic metrics (like spam reports, delivery errors etc) otherwise available through the Gmail Postmaster Tools UI currently.

Examples:

require 'google/apis/gmailpostmastertools_v2'

Gmailpostmastertools = Google::Apis::GmailpostmastertoolsV2 # Alias the module
service = Gmailpostmastertools::PostmasterToolsService.new

See Also:

Constant Summary collapse

DEFAULT_ENDPOINT_TEMPLATE =
"https://gmailpostmastertools.$UNIVERSE_DOMAIN$/"

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initializePostmasterToolsService

Returns a new instance of PostmasterToolsService.



49
50
51
52
53
54
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 49

def initialize
  super(DEFAULT_ENDPOINT_TEMPLATE, '',
        client_name: 'google-apis-gmailpostmastertools_v2',
        client_version: Google::Apis::GmailpostmastertoolsV2::GEM_VERSION)
  @batch_path = 'batch'
end

Instance Attribute Details

#keyString

Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.

Returns:

  • (String)

    API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.



42
43
44
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 42

def key
  @key
end

#quota_userString

Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

Returns:

  • (String)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.



47
48
49
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 47

def quota_user
  @quota_user
end

Instance Method Details

#batch_query_domain_stats(batch_query_domain_stats_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::BatchQueryDomainStatsResponse

Executes a batch of QueryDomainStats requests for multiple domains. Returns PERMISSION_DENIED if you don't have permission to access DomainStats for any of the requested domains.

Parameters:

  • batch_query_domain_stats_request_object (Google::Apis::GmailpostmastertoolsV2::BatchQueryDomainStatsRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



77
78
79
80
81
82
83
84
85
86
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 77

def batch_query_domain_stats(batch_query_domain_stats_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v2/domainStats:batchQuery', options)
  command.request_representation = Google::Apis::GmailpostmastertoolsV2::BatchQueryDomainStatsRequest::Representation
  command.request_object = batch_query_domain_stats_request_object
  command.response_representation = Google::Apis::GmailpostmastertoolsV2::BatchQueryDomainStatsResponse::Representation
  command.response_class = Google::Apis::GmailpostmastertoolsV2::BatchQueryDomainStatsResponse
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#create_domain(create_domain_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::Domain

Developer Preview: Adds a domain to the user's account. Returns INVALID_ARGUMENT if a domain is not provided. Returns ALREADY_EXISTS if the domain is already registered by the user.

Parameters:

  • create_domain_request_object (Google::Apis::GmailpostmastertoolsV2::CreateDomainRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



110
111
112
113
114
115
116
117
118
119
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 110

def create_domain(create_domain_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v2/domains', options)
  command.request_representation = Google::Apis::GmailpostmastertoolsV2::CreateDomainRequest::Representation
  command.request_object = create_domain_request_object
  command.response_representation = Google::Apis::GmailpostmastertoolsV2::Domain::Representation
  command.response_class = Google::Apis::GmailpostmastertoolsV2::Domain
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#create_user(parent, create_user_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::User

Developer Preview: Creates a user, who has access to a domain. Returns INVALID_ARGUMENT if a user is not provided.

Parameters:

  • parent (String)

    Required. The parent resource where this user will be created. Format: domains/ domain

  • create_user_request_object (Google::Apis::GmailpostmastertoolsV2::CreateUserRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



390
391
392
393
394
395
396
397
398
399
400
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 390

def create_user(parent, create_user_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v2/{+parent}/users', options)
  command.request_representation = Google::Apis::GmailpostmastertoolsV2::CreateUserRequest::Representation
  command.request_object = create_user_request_object
  command.response_representation = Google::Apis::GmailpostmastertoolsV2::User::Representation
  command.response_class = Google::Apis::GmailpostmastertoolsV2::User
  command.params['parent'] = parent unless parent.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#delete_domain(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::Empty

Developer Preview: Deletes a domain from the user's account. Returns NOT_FOUND if the domain is not registered by the user.

Parameters:

  • name (String)

    Required. The domain to delete.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



143
144
145
146
147
148
149
150
151
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 143

def delete_domain(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:delete, 'v2/{+name}', options)
  command.response_representation = Google::Apis::GmailpostmastertoolsV2::Empty::Representation
  command.response_class = Google::Apis::GmailpostmastertoolsV2::Empty
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#delete_domain_user(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::Empty

Developer Preview: Deletes a user from a domain. Returns NOT_FOUND if the user does not exist.

Parameters:

  • name (String)

    Required. The resource name of the user to delete. Format: domains/domain/ users/user

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



424
425
426
427
428
429
430
431
432
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 424

def delete_domain_user(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:delete, 'v2/{+name}', options)
  command.response_representation = Google::Apis::GmailpostmastertoolsV2::Empty::Representation
  command.response_class = Google::Apis::GmailpostmastertoolsV2::Empty
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_domain(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::Domain

Retrieves detailed information about a domain registered by you. Returns NOT_FOUND if the domain is not registered by you. Domain represents the metadata of a domain that has been registered within the system and linked to a user.

Parameters:

  • name (String)

    Required. The resource name of the domain. Format: domains/domain_name``, where domain_name is the fully qualified domain name (i.e., mymail.mydomain. com).

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



178
179
180
181
182
183
184
185
186
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 178

def get_domain(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v2/{+name}', options)
  command.response_representation = Google::Apis::GmailpostmastertoolsV2::Domain::Representation
  command.response_class = Google::Apis::GmailpostmastertoolsV2::Domain
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_domain_compliance_status(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::DomainComplianceStatus

Retrieves the compliance status for a given domain. Returns PERMISSION_DENIED if you don't have permission to access compliance status for the domain.

Parameters:

  • name (String)

    Required. The resource name of the domain's compliance status to retrieve. Format: domains/domain_id/complianceStatus.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



210
211
212
213
214
215
216
217
218
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 210

def get_domain_compliance_status(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v2/{+name}', options)
  command.response_representation = Google::Apis::GmailpostmastertoolsV2::DomainComplianceStatus::Representation
  command.response_class = Google::Apis::GmailpostmastertoolsV2::DomainComplianceStatus
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_domain_user(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::User

Developer Preview: Retrieves detailed information about a user that has access to a domain. Returns NOT_FOUND if the user does not exist.

Parameters:

  • name (String)

    Required. The resource name of the user to retrieve. Format: domains/domain/ users/user``

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



457
458
459
460
461
462
463
464
465
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 457

def get_domain_user(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v2/{+name}', options)
  command.response_representation = Google::Apis::GmailpostmastertoolsV2::User::Representation
  command.response_class = Google::Apis::GmailpostmastertoolsV2::User
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_domain_verification_token(name, verification_method: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::DomainVerificationToken

Developer Preview: Gets a verification token used for verifying a user's ownership over a domain.

Parameters:

  • name (String)

    Required. The resource name of the verification token to retrieve. Format: domains/domain/verificationToken

  • verification_method (String) (defaults to: nil)

    Required. The verification method used. Must be specified, i.e. TXT or CNAME.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



244
245
246
247
248
249
250
251
252
253
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 244

def get_domain_verification_token(name, verification_method: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v2/{+name}', options)
  command.response_representation = Google::Apis::GmailpostmastertoolsV2::DomainVerificationToken::Representation
  command.response_class = Google::Apis::GmailpostmastertoolsV2::DomainVerificationToken
  command.params['name'] = name unless name.nil?
  command.query['verificationMethod'] = verification_method unless verification_method.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_domain_users(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::ListUsersResponse

Developer Preview: Lists the users that have access to a domain.

Parameters:

  • parent (String)

    Required. The parent resource name for which to list users. Format: domains/ domain``

  • page_size (Fixnum) (defaults to: nil)

    Optional. Requested page size. Server may return fewer users than requested. If unspecified, the default value for this field is 10. The maximum value for this field is 200.

  • page_token (String) (defaults to: nil)

    Optional. The next_page_token value returned from a previous List request, if any.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



496
497
498
499
500
501
502
503
504
505
506
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 496

def list_domain_users(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v2/{+parent}/users', options)
  command.response_representation = Google::Apis::GmailpostmastertoolsV2::ListUsersResponse::Representation
  command.response_class = Google::Apis::GmailpostmastertoolsV2::ListUsersResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_domains(page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::ListDomainsResponse

Retrieves a list of all domains registered by you, along with their corresponding metadata. The order of domains in the response is unspecified and non-deterministic. Newly registered domains will not necessarily be added to the end of this list.

Parameters:

  • page_size (Fixnum) (defaults to: nil)

    Optional. Requested page size. Server may return fewer domains than requested. If unspecified, the default value for this field is 10. The maximum value for this field is 200.

  • page_token (String) (defaults to: nil)

    Optional. The next_page_token value returned from a previous List request, if any.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



283
284
285
286
287
288
289
290
291
292
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 283

def list_domains(page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v2/domains', options)
  command.response_representation = Google::Apis::GmailpostmastertoolsV2::ListDomainsResponse::Representation
  command.response_class = Google::Apis::GmailpostmastertoolsV2::ListDomainsResponse
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#patch_domain_user(name, user_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::User

Developer Preview: Updates a user for a domain. Only Owners and Admins can execute this RPC, only a user' s domain permission will be allowed to be updated. Returns NOT_FOUND if the user does not exist. Returns INVALID_ARGUMENT if a permission is not provided or is PERMISSION_UNSPECIFIED, NONE, or OWNER.

Parameters:

  • name (String)

    Identifier. The resource name of the user. Format: users/user Note: user is the user's email address.

  • user_object (Google::Apis::GmailpostmastertoolsV2::User) (defaults to: nil)
  • update_mask (String) (defaults to: nil)

    The list of fields to update.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



536
537
538
539
540
541
542
543
544
545
546
547
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 536

def patch_domain_user(name, user_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:patch, 'v2/{+name}', options)
  command.request_representation = Google::Apis::GmailpostmastertoolsV2::User::Representation
  command.request_object = user_object
  command.response_representation = Google::Apis::GmailpostmastertoolsV2::User::Representation
  command.response_class = Google::Apis::GmailpostmastertoolsV2::User
  command.params['name'] = name unless name.nil?
  command.query['updateMask'] = update_mask unless update_mask.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#query_domain_stats(parent, query_domain_stats_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::QueryDomainStatsResponse

Retrieves a list of domain statistics for a given domain and time period. Returns statistics only for dates where data is available. Returns PERMISSION_DENIED if you don't have permission to access DomainStats for the domain.

Parameters:

  • parent (String)

    Required. The parent resource name where the stats are queried. Format: domains/domain

  • query_domain_stats_request_object (Google::Apis::GmailpostmastertoolsV2::QueryDomainStatsRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



354
355
356
357
358
359
360
361
362
363
364
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 354

def query_domain_stats(parent, query_domain_stats_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v2/{+parent}/domainStats:query', options)
  command.request_representation = Google::Apis::GmailpostmastertoolsV2::QueryDomainStatsRequest::Representation
  command.request_object = query_domain_stats_request_object
  command.response_representation = Google::Apis::GmailpostmastertoolsV2::QueryDomainStatsResponse::Representation
  command.response_class = Google::Apis::GmailpostmastertoolsV2::QueryDomainStatsResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#verify_domain(name, verify_domain_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::VerifyDomainResponse

Developer Preview: Verifies a user's ownership of a domain at the DNS level. Note that this is distinct from checking if the user has OWNER status within IRDB.

Parameters:

  • name (String)

    Required. The domain to verify.

  • verify_domain_request_object (Google::Apis::GmailpostmastertoolsV2::VerifyDomainRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



317
318
319
320
321
322
323
324
325
326
327
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 317

def verify_domain(name, verify_domain_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v2/{+name}:verify', options)
  command.request_representation = Google::Apis::GmailpostmastertoolsV2::VerifyDomainRequest::Representation
  command.request_object = verify_domain_request_object
  command.response_representation = Google::Apis::GmailpostmastertoolsV2::VerifyDomainResponse::Representation
  command.response_class = Google::Apis::GmailpostmastertoolsV2::VerifyDomainResponse
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end