Class: Google::Apis::GmailpostmastertoolsV2::QueryDomainStatsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gmailpostmastertools_v2/classes.rb,
lib/google/apis/gmailpostmastertools_v2/representations.rb,
lib/google/apis/gmailpostmastertools_v2/representations.rb

Overview

Response message for QueryDomainStats.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueryDomainStatsResponse

Returns a new instance of QueryDomainStatsResponse.



787
788
789
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 787

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#domain_statsArray<Google::Apis::GmailpostmastertoolsV2::DomainStat>

The list of domain statistics. Each DomainStat object contains the value for a metric requested in the QueryDomainStatsRequest. Corresponds to the JSON property domainStats



779
780
781
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 779

def domain_stats
  @domain_stats
end

#next_page_tokenString

Token to retrieve the next page of results, or empty if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


785
786
787
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 785

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



792
793
794
795
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 792

def update!(**args)
  @domain_stats = args[:domain_stats] if args.key?(:domain_stats)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end