Class: Google::Apis::GmailpostmastertoolsV2::User
- Inherits:
-
Object
- Object
- Google::Apis::GmailpostmastertoolsV2::User
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gmailpostmastertools_v2/classes.rb,
lib/google/apis/gmailpostmastertools_v2/representations.rb,
lib/google/apis/gmailpostmastertools_v2/representations.rb
Overview
Developer Preview: Information about a user's access to a domain.
Instance Attribute Summary collapse
-
#access_granter ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#permission ⇒ String
The permission level that the user has for the specified domain.
-
#user ⇒ String
The user's email address.
Instance Method Summary collapse
-
#initialize(**args) ⇒ User
constructor
A new instance of User.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ User
Returns a new instance of User.
955 956 957 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 955 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_granter ⇒ String
Output only. The user that added the current user.
Corresponds to the JSON property accessGranter
932 933 934 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 932 def access_granter @access_granter end |
#create_time ⇒ String
Output only. The time the user was granted access.
Corresponds to the JSON property createTime
937 938 939 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 937 def create_time @create_time end |
#name ⇒ String
Identifier. The resource name of the user. Format: users/user Note: user
is the user's email address.
Corresponds to the JSON property name
943 944 945 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 943 def name @name end |
#permission ⇒ String
The permission level that the user has for the specified domain.
Corresponds to the JSON property permission
948 949 950 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 948 def @permission end |
#user ⇒ String
The user's email address.
Corresponds to the JSON property user
953 954 955 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 953 def user @user end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
960 961 962 963 964 965 966 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 960 def update!(**args) @access_granter = args[:access_granter] if args.key?(:access_granter) @create_time = args[:create_time] if args.key?(:create_time) @name = args[:name] if args.key?(:name) @permission = args[:permission] if args.key?(:permission) @user = args[:user] if args.key?(:user) end |