Class: Google::Apis::GmailpostmastertoolsV2::BatchQueryDomainStatsResult
- Inherits:
-
Object
- Object
- Google::Apis::GmailpostmastertoolsV2::BatchQueryDomainStatsResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gmailpostmastertools_v2/classes.rb,
lib/google/apis/gmailpostmastertools_v2/representations.rb,
lib/google/apis/gmailpostmastertools_v2/representations.rb
Overview
Represents the result of a single QueryDomainStatsRequest within a batch.
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::GmailpostmastertoolsV2::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#response ⇒ Google::Apis::GmailpostmastertoolsV2::QueryDomainStatsResponse
Response message for QueryDomainStats.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BatchQueryDomainStatsResult
constructor
A new instance of BatchQueryDomainStatsResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BatchQueryDomainStatsResult
Returns a new instance of BatchQueryDomainStatsResult.
104 105 106 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 104 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::GmailpostmastertoolsV2::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
97 98 99 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 97 def error @error end |
#response ⇒ Google::Apis::GmailpostmastertoolsV2::QueryDomainStatsResponse
Response message for QueryDomainStats.
Corresponds to the JSON property response
102 103 104 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 102 def response @response end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
109 110 111 112 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 109 def update!(**args) @error = args[:error] if args.key?(:error) @response = args[:response] if args.key?(:response) end |