Class: Google::Apis::GmailpostmastertoolsV2::CreateUserRequest
- Inherits:
-
Object
- Object
- Google::Apis::GmailpostmastertoolsV2::CreateUserRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gmailpostmastertools_v2/classes.rb,
lib/google/apis/gmailpostmastertools_v2/representations.rb,
lib/google/apis/gmailpostmastertools_v2/representations.rb
Overview
Developer Preview: Request message for CreateUser.
Instance Attribute Summary collapse
-
#permission ⇒ String
Optional.
-
#user_id ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreateUserRequest
constructor
A new instance of CreateUserRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CreateUserRequest
Returns a new instance of CreateUserRequest.
195 196 197 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 195 def initialize(**args) update!(**args) end |
Instance Attribute Details
#permission ⇒ String
Optional. Specifies the permission level to give the user for the specified
domain. If not specified, the default value for this field is READER.
Corresponds to the JSON property permission
188 189 190 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 188 def @permission end |
#user_id ⇒ String
Required. The user to create.
Corresponds to the JSON property userId
193 194 195 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 193 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
200 201 202 203 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 200 def update!(**args) @permission = args[:permission] if args.key?(:permission) @user_id = args[:user_id] if args.key?(:user_id) end |