Class: Google::Apis::GmailpostmastertoolsV2::Domain

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gmailpostmastertools_v2/classes.rb,
lib/google/apis/gmailpostmastertools_v2/representations.rb,
lib/google/apis/gmailpostmastertools_v2/representations.rb

Overview

Information about a domain registered by the user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Domain

Returns a new instance of Domain.



310
311
312
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 310

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Immutable. The timestamp at which the domain was added to the user's account. Corresponds to the JSON property createTime

Returns:

  • (String)


285
286
287
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 285

def create_time
  @create_time
end

#last_verify_timeString

The timestamp at which the domain was last verified by the user. Corresponds to the JSON property lastVerifyTime

Returns:

  • (String)


290
291
292
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 290

def last_verify_time
  @last_verify_time
end

#nameString

Identifier. The resource name of the domain. Format: domains/domain_name`, where domain_name is the fully qualified domain name (i.e., mymail.mydomain. com). Corresponds to the JSON propertyname`

Returns:

  • (String)


297
298
299
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 297

def name
  @name
end

#permissionString

Output only. User's permission of this domain. Corresponds to the JSON property permission

Returns:

  • (String)


302
303
304
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 302

def permission
  @permission
end

#verification_stateString

Output only. Information about a user's verification history and properties for the domain. Corresponds to the JSON property verificationState

Returns:

  • (String)


308
309
310
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 308

def verification_state
  @verification_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



315
316
317
318
319
320
321
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 315

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @last_verify_time = args[:last_verify_time] if args.key?(:last_verify_time)
  @name = args[:name] if args.key?(:name)
  @permission = args[:permission] if args.key?(:permission)
  @verification_state = args[:verification_state] if args.key?(:verification_state)
end