Class: Google::Apis::GmailpostmastertoolsV2::Domain
- Inherits:
-
Object
- Object
- Google::Apis::GmailpostmastertoolsV2::Domain
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gmailpostmastertools_v2/classes.rb,
lib/google/apis/gmailpostmastertools_v2/representations.rb,
lib/google/apis/gmailpostmastertools_v2/representations.rb
Overview
Information about a domain registered by the user.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#last_verify_time ⇒ String
The timestamp at which the domain was last verified by the user.
-
#name ⇒ String
Identifier.
-
#permission ⇒ String
Output only.
-
#verification_state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Domain
constructor
A new instance of Domain.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Domain
Returns a new instance of Domain.
310 311 312 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 310 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Immutable. The timestamp at which the domain was added to the
user's account.
Corresponds to the JSON property createTime
285 286 287 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 285 def create_time @create_time end |
#last_verify_time ⇒ String
The timestamp at which the domain was last verified by the user.
Corresponds to the JSON property lastVerifyTime
290 291 292 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 290 def last_verify_time @last_verify_time end |
#name ⇒ String
Identifier. The resource name of the domain. Format: domains/domain_name`,
where domain_name is the fully qualified domain name (i.e., mymail.mydomain.
com).
Corresponds to the JSON propertyname`
297 298 299 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 297 def name @name end |
#permission ⇒ String
Output only. User's permission of this domain.
Corresponds to the JSON property permission
302 303 304 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 302 def @permission end |
#verification_state ⇒ String
Output only. Information about a user's verification history and properties
for the domain.
Corresponds to the JSON property verificationState
308 309 310 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 308 def verification_state @verification_state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
315 316 317 318 319 320 321 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 315 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @last_verify_time = args[:last_verify_time] if args.key?(:last_verify_time) @name = args[:name] if args.key?(:name) @permission = args[:permission] if args.key?(:permission) @verification_state = args[:verification_state] if args.key?(:verification_state) end |