Class: Google::Apis::GmailpostmastertoolsV2::DomainComplianceData
- Inherits:
-
Object
- Object
- Google::Apis::GmailpostmastertoolsV2::DomainComplianceData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gmailpostmastertools_v2/classes.rb,
lib/google/apis/gmailpostmastertools_v2/representations.rb,
lib/google/apis/gmailpostmastertools_v2/representations.rb
Overview
Compliance data for a given domain.
Instance Attribute Summary collapse
-
#deliverability_status_verdict ⇒ Google::Apis::GmailpostmastertoolsV2::DeliverabilityStatusVerdict
Developer Preview: Verdict of domain deliverability status.
-
#domain_id ⇒ String
Domain that this data is for.
-
#honor_unsubscribe_verdict ⇒ Google::Apis::GmailpostmastertoolsV2::HonorUnsubscribeVerdict
Compliance verdict for whether a sender meets the unsubscribe honoring compliance requirement.
-
#one_click_unsubscribe_verdict ⇒ Google::Apis::GmailpostmastertoolsV2::OneClickUnsubscribeVerdict
Compliance verdict for whether a sender meets the one-click unsubscribe compliance requirement.
-
#row_data ⇒ Array<Google::Apis::GmailpostmastertoolsV2::ComplianceRowData>
Data for each of the rows of the table.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DomainComplianceData
constructor
A new instance of DomainComplianceData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DomainComplianceData
Returns a new instance of DomainComplianceData.
430 431 432 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 430 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deliverability_status_verdict ⇒ Google::Apis::GmailpostmastertoolsV2::DeliverabilityStatusVerdict
Developer Preview: Verdict
of domain deliverability status.
Corresponds to the JSON property deliverabilityStatusVerdict
405 406 407 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 405 def deliverability_status_verdict @deliverability_status_verdict end |
#domain_id ⇒ String
Domain that this data is for.
Corresponds to the JSON property domainId
410 411 412 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 410 def domain_id @domain_id end |
#honor_unsubscribe_verdict ⇒ Google::Apis::GmailpostmastertoolsV2::HonorUnsubscribeVerdict
Compliance verdict for whether a sender meets the unsubscribe honoring
compliance requirement.
Corresponds to the JSON property honorUnsubscribeVerdict
416 417 418 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 416 def honor_unsubscribe_verdict @honor_unsubscribe_verdict end |
#one_click_unsubscribe_verdict ⇒ Google::Apis::GmailpostmastertoolsV2::OneClickUnsubscribeVerdict
Compliance verdict for whether a sender meets the one-click unsubscribe
compliance requirement.
Corresponds to the JSON property oneClickUnsubscribeVerdict
422 423 424 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 422 def one_click_unsubscribe_verdict @one_click_unsubscribe_verdict end |
#row_data ⇒ Array<Google::Apis::GmailpostmastertoolsV2::ComplianceRowData>
Data for each of the rows of the table. Each message contains all the data
that backs a single row.
Corresponds to the JSON property rowData
428 429 430 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 428 def row_data @row_data end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
435 436 437 438 439 440 441 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 435 def update!(**args) @deliverability_status_verdict = args[:deliverability_status_verdict] if args.key?(:deliverability_status_verdict) @domain_id = args[:domain_id] if args.key?(:domain_id) @honor_unsubscribe_verdict = args[:honor_unsubscribe_verdict] if args.key?(:honor_unsubscribe_verdict) @one_click_unsubscribe_verdict = args[:one_click_unsubscribe_verdict] if args.key?(:one_click_unsubscribe_verdict) @row_data = args[:row_data] if args.key?(:row_data) end |