Class: Google::Apis::GmailpostmastertoolsV2::DomainComplianceData
- Inherits:
-
Object
- Object
- Google::Apis::GmailpostmastertoolsV2::DomainComplianceData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gmailpostmastertools_v2/classes.rb,
lib/google/apis/gmailpostmastertools_v2/representations.rb,
lib/google/apis/gmailpostmastertools_v2/representations.rb
Overview
Compliance data for a given domain.
Instance Attribute Summary collapse
-
#domain_id ⇒ String
Domain that this data is for.
-
#honor_unsubscribe_verdict ⇒ Google::Apis::GmailpostmastertoolsV2::HonorUnsubscribeVerdict
Compliance verdict for whether a sender meets the unsubscribe honoring compliance requirement.
-
#one_click_unsubscribe_verdict ⇒ Google::Apis::GmailpostmastertoolsV2::OneClickUnsubscribeVerdict
Compliance verdict for whether a sender meets the one-click unsubscribe compliance requirement.
-
#row_data ⇒ Array<Google::Apis::GmailpostmastertoolsV2::ComplianceRowData>
Data for each of the rows of the table.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DomainComplianceData
constructor
A new instance of DomainComplianceData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DomainComplianceData
Returns a new instance of DomainComplianceData.
351 352 353 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 351 def initialize(**args) update!(**args) end |
Instance Attribute Details
#domain_id ⇒ String
Domain that this data is for.
Corresponds to the JSON property domainId
331 332 333 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 331 def domain_id @domain_id end |
#honor_unsubscribe_verdict ⇒ Google::Apis::GmailpostmastertoolsV2::HonorUnsubscribeVerdict
Compliance verdict for whether a sender meets the unsubscribe honoring
compliance requirement.
Corresponds to the JSON property honorUnsubscribeVerdict
337 338 339 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 337 def honor_unsubscribe_verdict @honor_unsubscribe_verdict end |
#one_click_unsubscribe_verdict ⇒ Google::Apis::GmailpostmastertoolsV2::OneClickUnsubscribeVerdict
Compliance verdict for whether a sender meets the one-click unsubscribe
compliance requirement.
Corresponds to the JSON property oneClickUnsubscribeVerdict
343 344 345 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 343 def one_click_unsubscribe_verdict @one_click_unsubscribe_verdict end |
#row_data ⇒ Array<Google::Apis::GmailpostmastertoolsV2::ComplianceRowData>
Data for each of the rows of the table. Each message contains all the data
that backs a single row.
Corresponds to the JSON property rowData
349 350 351 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 349 def row_data @row_data end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
356 357 358 359 360 361 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 356 def update!(**args) @domain_id = args[:domain_id] if args.key?(:domain_id) @honor_unsubscribe_verdict = args[:honor_unsubscribe_verdict] if args.key?(:honor_unsubscribe_verdict) @one_click_unsubscribe_verdict = args[:one_click_unsubscribe_verdict] if args.key?(:one_click_unsubscribe_verdict) @row_data = args[:row_data] if args.key?(:row_data) end |