Class: Google::Apis::GmailpostmastertoolsV2::DomainStat
- Inherits:
-
Object
- Object
- Google::Apis::GmailpostmastertoolsV2::DomainStat
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gmailpostmastertools_v2/classes.rb,
lib/google/apis/gmailpostmastertools_v2/representations.rb,
lib/google/apis/gmailpostmastertools_v2/representations.rb
Overview
Email statistics for a domain for a specified time period or date.
Instance Attribute Summary collapse
-
#date ⇒ Google::Apis::GmailpostmastertoolsV2::Date
Represents a whole or partial calendar date, such as a birthday.
-
#metric ⇒ String
The user-defined name from MetricDefinition.name in the request, used to correlate this result with the requested metric.
-
#name ⇒ String
Output only.
-
#value ⇒ Google::Apis::GmailpostmastertoolsV2::StatisticValue
The actual value of a statistic.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DomainStat
constructor
A new instance of DomainStat.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DomainStat
Returns a new instance of DomainStat.
431 432 433 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 431 def initialize(**args) update!(**args) end |
Instance Attribute Details
#date ⇒ Google::Apis::GmailpostmastertoolsV2::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property date
410 411 412 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 410 def date @date end |
#metric ⇒ String
The user-defined name from MetricDefinition.name in the request, used to
correlate this result with the requested metric.
Corresponds to the JSON property metric
416 417 418 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 416 def metric @metric end |
#name ⇒ String
Output only. The resource name of the DomainStat resource. Format: domains/
domain/domainStats/domain_stat The domain_stat segment is an opaque,
server-generated ID. We recommend using the metric field to identify queried
metrics instead of parsing the name.
Corresponds to the JSON property name
424 425 426 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 424 def name @name end |
#value ⇒ Google::Apis::GmailpostmastertoolsV2::StatisticValue
The actual value of a statistic.
Corresponds to the JSON property value
429 430 431 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 429 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
436 437 438 439 440 441 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 436 def update!(**args) @date = args[:date] if args.key?(:date) @metric = args[:metric] if args.key?(:metric) @name = args[:name] if args.key?(:name) @value = args[:value] if args.key?(:value) end |