Class: Google::Apis::GmailpostmastertoolsV2::ListDomainsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gmailpostmastertools_v2/classes.rb,
lib/google/apis/gmailpostmastertools_v2/representations.rb,
lib/google/apis/gmailpostmastertools_v2/representations.rb

Overview

Response message for ListDomains.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListDomainsResponse

Returns a new instance of ListDomainsResponse.



486
487
488
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 486

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#domainsArray<Google::Apis::GmailpostmastertoolsV2::Domain>

The domains that have been registered by the user. Corresponds to the JSON property domains



478
479
480
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 478

def domains
  @domains
end

#next_page_tokenString

Token to retrieve the next page of results, or empty if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


484
485
486
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 484

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



491
492
493
494
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 491

def update!(**args)
  @domains = args[:domains] if args.key?(:domains)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end