Class: Google::Apis::GmailpostmastertoolsV2::ListUsersResponse
- Inherits:
-
Object
- Object
- Google::Apis::GmailpostmastertoolsV2::ListUsersResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gmailpostmastertools_v2/classes.rb,
lib/google/apis/gmailpostmastertools_v2/representations.rb,
lib/google/apis/gmailpostmastertools_v2/representations.rb
Overview
Developer Preview: Response message for ListUsers.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more results in the list.
-
#users ⇒ Array<Google::Apis::GmailpostmastertoolsV2::User>
The users that have access to the domain.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListUsersResponse
constructor
A new instance of ListUsersResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListUsersResponse
Returns a new instance of ListUsersResponse.
642 643 644 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 642 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more
results in the list.
Corresponds to the JSON property nextPageToken
635 636 637 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 635 def next_page_token @next_page_token end |
#users ⇒ Array<Google::Apis::GmailpostmastertoolsV2::User>
The users that have access to the domain.
Corresponds to the JSON property users
640 641 642 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 640 def users @users end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
647 648 649 650 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 647 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @users = args[:users] if args.key?(:users) end |