Class: Google::Apis::GmailpostmastertoolsV2::PostmasterToolsService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::GmailpostmastertoolsV2::PostmasterToolsService
- Defined in:
- lib/google/apis/gmailpostmastertools_v2/service.rb
Overview
Gmail Postmaster Tools API
The Postmaster Tools API is a RESTful API that provides programmatic access to email traffic metrics (like spam reports, delivery errors etc) otherwise available through the Gmail Postmaster Tools UI currently.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://gmailpostmastertools.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#batch_query_domain_stats(batch_query_domain_stats_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::BatchQueryDomainStatsResponse
Executes a batch of QueryDomainStats requests for multiple domains.
-
#create_domain(create_domain_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::Domain
Developer Preview: Adds a domain to the user's account.
-
#create_user(parent, create_user_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::User
Developer Preview: Creates a user, who has access to a domain.
-
#delete_domain(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::Empty
Developer Preview: Deletes a domain from the user's account.
-
#delete_domain_user(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::Empty
Developer Preview: Deletes a user from a domain.
-
#get_domain(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::Domain
Retrieves detailed information about a domain registered by you.
-
#get_domain_compliance_status(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::DomainComplianceStatus
Retrieves the compliance status for a given domain.
-
#get_domain_user(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::User
Developer Preview: Retrieves detailed information about a user that has access to a domain.
-
#get_domain_verification_token(name, verification_method: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::DomainVerificationToken
Developer Preview: Gets a verification token used for verifying a user's ownership over a domain.
-
#initialize ⇒ PostmasterToolsService
constructor
A new instance of PostmasterToolsService.
-
#list_domain_users(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::ListUsersResponse
Developer Preview: Lists the users that have access to a domain.
-
#list_domains(page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::ListDomainsResponse
Retrieves a list of all domains registered by you, along with their corresponding metadata.
-
#patch_domain_user(name, user_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::User
Developer Preview: Updates a user for a domain.
-
#query_domain_stats(parent, query_domain_stats_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::QueryDomainStatsResponse
Retrieves a list of domain statistics for a given domain and time period.
-
#verify_domain(name, verify_domain_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::VerifyDomainResponse
Developer Preview: Verifies a user's ownership of a domain at the DNS level.
Constructor Details
#initialize ⇒ PostmasterToolsService
Returns a new instance of PostmasterToolsService.
49 50 51 52 53 54 |
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 49 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-gmailpostmastertools_v2', client_version: Google::Apis::GmailpostmastertoolsV2::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
42 43 44 |
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 42 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
47 48 49 |
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 47 def quota_user @quota_user end |
Instance Method Details
#batch_query_domain_stats(batch_query_domain_stats_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::BatchQueryDomainStatsResponse
Executes a batch of QueryDomainStats requests for multiple domains. Returns PERMISSION_DENIED if you don't have permission to access DomainStats for any of the requested domains.
77 78 79 80 81 82 83 84 85 86 |
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 77 def batch_query_domain_stats(batch_query_domain_stats_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/domainStats:batchQuery', ) command.request_representation = Google::Apis::GmailpostmastertoolsV2::BatchQueryDomainStatsRequest::Representation command.request_object = batch_query_domain_stats_request_object command.response_representation = Google::Apis::GmailpostmastertoolsV2::BatchQueryDomainStatsResponse::Representation command.response_class = Google::Apis::GmailpostmastertoolsV2::BatchQueryDomainStatsResponse command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_domain(create_domain_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::Domain
Developer Preview: Adds a domain to the user's account. Returns INVALID_ARGUMENT if a domain is not provided. Returns ALREADY_EXISTS if the domain is already registered by the user.
110 111 112 113 114 115 116 117 118 119 |
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 110 def create_domain(create_domain_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/domains', ) command.request_representation = Google::Apis::GmailpostmastertoolsV2::CreateDomainRequest::Representation command.request_object = create_domain_request_object command.response_representation = Google::Apis::GmailpostmastertoolsV2::Domain::Representation command.response_class = Google::Apis::GmailpostmastertoolsV2::Domain command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_user(parent, create_user_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::User
Developer Preview: Creates a user, who has access to a domain. Returns INVALID_ARGUMENT if a user is not provided.
390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 390 def create_user(parent, create_user_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+parent}/users', ) command.request_representation = Google::Apis::GmailpostmastertoolsV2::CreateUserRequest::Representation command.request_object = create_user_request_object command.response_representation = Google::Apis::GmailpostmastertoolsV2::User::Representation command.response_class = Google::Apis::GmailpostmastertoolsV2::User command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_domain(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::Empty
Developer Preview: Deletes a domain from the user's account. Returns NOT_FOUND if the domain is not registered by the user.
143 144 145 146 147 148 149 150 151 |
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 143 def delete_domain(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v2/{+name}', ) command.response_representation = Google::Apis::GmailpostmastertoolsV2::Empty::Representation command.response_class = Google::Apis::GmailpostmastertoolsV2::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_domain_user(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::Empty
Developer Preview: Deletes a user from a domain. Returns NOT_FOUND if the user does not exist.
424 425 426 427 428 429 430 431 432 |
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 424 def delete_domain_user(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v2/{+name}', ) command.response_representation = Google::Apis::GmailpostmastertoolsV2::Empty::Representation command.response_class = Google::Apis::GmailpostmastertoolsV2::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_domain(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::Domain
Retrieves detailed information about a domain registered by you. Returns NOT_FOUND if the domain is not registered by you. Domain represents the metadata of a domain that has been registered within the system and linked to a user.
178 179 180 181 182 183 184 185 186 |
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 178 def get_domain(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}', ) command.response_representation = Google::Apis::GmailpostmastertoolsV2::Domain::Representation command.response_class = Google::Apis::GmailpostmastertoolsV2::Domain command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_domain_compliance_status(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::DomainComplianceStatus
Retrieves the compliance status for a given domain. Returns PERMISSION_DENIED if you don't have permission to access compliance status for the domain.
210 211 212 213 214 215 216 217 218 |
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 210 def get_domain_compliance_status(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}', ) command.response_representation = Google::Apis::GmailpostmastertoolsV2::DomainComplianceStatus::Representation command.response_class = Google::Apis::GmailpostmastertoolsV2::DomainComplianceStatus command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_domain_user(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::User
Developer Preview: Retrieves detailed information about a user that has access to a domain. Returns NOT_FOUND if the user does not exist.
457 458 459 460 461 462 463 464 465 |
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 457 def get_domain_user(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}', ) command.response_representation = Google::Apis::GmailpostmastertoolsV2::User::Representation command.response_class = Google::Apis::GmailpostmastertoolsV2::User command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_domain_verification_token(name, verification_method: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::DomainVerificationToken
Developer Preview: Gets a verification token used for verifying a user's ownership over a domain.
244 245 246 247 248 249 250 251 252 253 |
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 244 def get_domain_verification_token(name, verification_method: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}', ) command.response_representation = Google::Apis::GmailpostmastertoolsV2::DomainVerificationToken::Representation command.response_class = Google::Apis::GmailpostmastertoolsV2::DomainVerificationToken command.params['name'] = name unless name.nil? command.query['verificationMethod'] = verification_method unless verification_method.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_domain_users(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::ListUsersResponse
Developer Preview: Lists the users that have access to a domain.
496 497 498 499 500 501 502 503 504 505 506 |
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 496 def list_domain_users(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+parent}/users', ) command.response_representation = Google::Apis::GmailpostmastertoolsV2::ListUsersResponse::Representation command.response_class = Google::Apis::GmailpostmastertoolsV2::ListUsersResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_domains(page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::ListDomainsResponse
Retrieves a list of all domains registered by you, along with their corresponding metadata. The order of domains in the response is unspecified and non-deterministic. Newly registered domains will not necessarily be added to the end of this list.
283 284 285 286 287 288 289 290 291 292 |
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 283 def list_domains(page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/domains', ) command.response_representation = Google::Apis::GmailpostmastertoolsV2::ListDomainsResponse::Representation command.response_class = Google::Apis::GmailpostmastertoolsV2::ListDomainsResponse command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_domain_user(name, user_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::User
Developer Preview: Updates a user for a domain. Only Owners and Admins can execute this RPC, only a user' s domain permission will be allowed to be updated. Returns NOT_FOUND if the user does not exist. Returns INVALID_ARGUMENT if a permission is not provided or is PERMISSION_UNSPECIFIED, NONE, or OWNER.
536 537 538 539 540 541 542 543 544 545 546 547 |
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 536 def patch_domain_user(name, user_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v2/{+name}', ) command.request_representation = Google::Apis::GmailpostmastertoolsV2::User::Representation command.request_object = user_object command.response_representation = Google::Apis::GmailpostmastertoolsV2::User::Representation command.response_class = Google::Apis::GmailpostmastertoolsV2::User command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#query_domain_stats(parent, query_domain_stats_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::QueryDomainStatsResponse
Retrieves a list of domain statistics for a given domain and time period. Returns statistics only for dates where data is available. Returns PERMISSION_DENIED if you don't have permission to access DomainStats for the domain.
354 355 356 357 358 359 360 361 362 363 364 |
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 354 def query_domain_stats(parent, query_domain_stats_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+parent}/domainStats:query', ) command.request_representation = Google::Apis::GmailpostmastertoolsV2::QueryDomainStatsRequest::Representation command.request_object = query_domain_stats_request_object command.response_representation = Google::Apis::GmailpostmastertoolsV2::QueryDomainStatsResponse::Representation command.response_class = Google::Apis::GmailpostmastertoolsV2::QueryDomainStatsResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#verify_domain(name, verify_domain_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::VerifyDomainResponse
Developer Preview: Verifies a user's ownership of a domain at the DNS level. Note that this is distinct from checking if the user has OWNER status within IRDB.
317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 317 def verify_domain(name, verify_domain_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+name}:verify', ) command.request_representation = Google::Apis::GmailpostmastertoolsV2::VerifyDomainRequest::Representation command.request_object = verify_domain_request_object command.response_representation = Google::Apis::GmailpostmastertoolsV2::VerifyDomainResponse::Representation command.response_class = Google::Apis::GmailpostmastertoolsV2::VerifyDomainResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |