Class: Google::Apis::GmailpostmastertoolsV2::PostmasterToolsService

Inherits:
Core::BaseService
  • Object
show all
Defined in:
lib/google/apis/gmailpostmastertools_v2/service.rb

Overview

Gmail Postmaster Tools API

The Postmaster Tools API is a RESTful API that provides programmatic access to email traffic metrics (like spam reports, delivery errors etc) otherwise available through the Gmail Postmaster Tools UI currently.

Examples:

require 'google/apis/gmailpostmastertools_v2'

Gmailpostmastertools = Google::Apis::GmailpostmastertoolsV2 # Alias the module
service = Gmailpostmastertools::PostmasterToolsService.new

See Also:

Constant Summary collapse

DEFAULT_ENDPOINT_TEMPLATE =
"https://gmailpostmastertools.$UNIVERSE_DOMAIN$/"

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initializePostmasterToolsService

Returns a new instance of PostmasterToolsService.



49
50
51
52
53
54
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 49

def initialize
  super(DEFAULT_ENDPOINT_TEMPLATE, '',
        client_name: 'google-apis-gmailpostmastertools_v2',
        client_version: Google::Apis::GmailpostmastertoolsV2::GEM_VERSION)
  @batch_path = 'batch'
end

Instance Attribute Details

#keyString

Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.

Returns:

  • (String)

    API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.



42
43
44
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 42

def key
  @key
end

#quota_userString

Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

Returns:

  • (String)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.



47
48
49
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 47

def quota_user
  @quota_user
end

Instance Method Details

#batch_query_domain_stats(batch_query_domain_stats_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::BatchQueryDomainStatsResponse

Executes a batch of QueryDomainStats requests for multiple domains. Returns PERMISSION_DENIED if you don't have permission to access DomainStats for any of the requested domains.

Parameters:

  • batch_query_domain_stats_request_object (Google::Apis::GmailpostmastertoolsV2::BatchQueryDomainStatsRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



77
78
79
80
81
82
83
84
85
86
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 77

def batch_query_domain_stats(batch_query_domain_stats_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v2/domainStats:batchQuery', options)
  command.request_representation = Google::Apis::GmailpostmastertoolsV2::BatchQueryDomainStatsRequest::Representation
  command.request_object = batch_query_domain_stats_request_object
  command.response_representation = Google::Apis::GmailpostmastertoolsV2::BatchQueryDomainStatsResponse::Representation
  command.response_class = Google::Apis::GmailpostmastertoolsV2::BatchQueryDomainStatsResponse
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_domain(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::Domain

Retrieves detailed information about a domain registered by you. Returns NOT_FOUND if the domain is not registered by you. Domain represents the metadata of a domain that has been registered within the system and linked to a user.

Parameters:

  • name (String)

    Required. The resource name of the domain. Format: domains/domain_name``, where domain_name is the fully qualified domain name (i.e., mymail.mydomain. com).

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



113
114
115
116
117
118
119
120
121
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 113

def get_domain(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v2/{+name}', options)
  command.response_representation = Google::Apis::GmailpostmastertoolsV2::Domain::Representation
  command.response_class = Google::Apis::GmailpostmastertoolsV2::Domain
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_domain_compliance_status(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::DomainComplianceStatus

Retrieves the compliance status for a given domain. Returns PERMISSION_DENIED if you don't have permission to access compliance status for the domain.

Parameters:

  • name (String)

    Required. The resource name of the domain's compliance status to retrieve. Format: domains/domain_id/complianceStatus.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



145
146
147
148
149
150
151
152
153
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 145

def get_domain_compliance_status(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v2/{+name}', options)
  command.response_representation = Google::Apis::GmailpostmastertoolsV2::DomainComplianceStatus::Representation
  command.response_class = Google::Apis::GmailpostmastertoolsV2::DomainComplianceStatus
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_domains(page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::ListDomainsResponse

Retrieves a list of all domains registered by you, along with their corresponding metadata. The order of domains in the response is unspecified and non-deterministic. Newly registered domains will not necessarily be added to the end of this list.

Parameters:

  • page_size (Fixnum) (defaults to: nil)

    Optional. Requested page size. Server may return fewer domains than requested. If unspecified, the default value for this field is 10. The maximum value for this field is 200.

  • page_token (String) (defaults to: nil)

    Optional. The next_page_token value returned from a previous List request, if any.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



183
184
185
186
187
188
189
190
191
192
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 183

def list_domains(page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v2/domains', options)
  command.response_representation = Google::Apis::GmailpostmastertoolsV2::ListDomainsResponse::Representation
  command.response_class = Google::Apis::GmailpostmastertoolsV2::ListDomainsResponse
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#query_domain_stats(parent, query_domain_stats_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::QueryDomainStatsResponse

Retrieves a list of domain statistics for a given domain and time period. Returns statistics only for dates where data is available. Returns PERMISSION_DENIED if you don't have permission to access DomainStats for the domain.

Parameters:

  • parent (String)

    Required. The parent resource name where the stats are queried. Format: domains/domain

  • query_domain_stats_request_object (Google::Apis::GmailpostmastertoolsV2::QueryDomainStatsRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



219
220
221
222
223
224
225
226
227
228
229
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 219

def query_domain_stats(parent, query_domain_stats_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v2/{+parent}/domainStats:query', options)
  command.request_representation = Google::Apis::GmailpostmastertoolsV2::QueryDomainStatsRequest::Representation
  command.request_object = query_domain_stats_request_object
  command.response_representation = Google::Apis::GmailpostmastertoolsV2::QueryDomainStatsResponse::Representation
  command.response_class = Google::Apis::GmailpostmastertoolsV2::QueryDomainStatsResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end