Class: Google::Apis::GmailpostmastertoolsV2::PostmasterToolsService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::GmailpostmastertoolsV2::PostmasterToolsService
- Defined in:
- lib/google/apis/gmailpostmastertools_v2/service.rb
Overview
Gmail Postmaster Tools API
The Postmaster Tools API is a RESTful API that provides programmatic access to email traffic metrics (like spam reports, delivery errors etc) otherwise available through the Gmail Postmaster Tools UI currently.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://gmailpostmastertools.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#batch_query_domain_stats(batch_query_domain_stats_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::BatchQueryDomainStatsResponse
Executes a batch of QueryDomainStats requests for multiple domains.
-
#get_domain(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::Domain
Retrieves detailed information about a domain registered by you.
-
#get_domain_compliance_status(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::DomainComplianceStatus
Retrieves the compliance status for a given domain.
-
#initialize ⇒ PostmasterToolsService
constructor
A new instance of PostmasterToolsService.
-
#list_domains(page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::ListDomainsResponse
Retrieves a list of all domains registered by you, along with their corresponding metadata.
-
#query_domain_stats(parent, query_domain_stats_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::QueryDomainStatsResponse
Retrieves a list of domain statistics for a given domain and time period.
Constructor Details
#initialize ⇒ PostmasterToolsService
Returns a new instance of PostmasterToolsService.
49 50 51 52 53 54 |
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 49 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-gmailpostmastertools_v2', client_version: Google::Apis::GmailpostmastertoolsV2::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
42 43 44 |
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 42 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
47 48 49 |
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 47 def quota_user @quota_user end |
Instance Method Details
#batch_query_domain_stats(batch_query_domain_stats_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::BatchQueryDomainStatsResponse
Executes a batch of QueryDomainStats requests for multiple domains. Returns PERMISSION_DENIED if you don't have permission to access DomainStats for any of the requested domains.
77 78 79 80 81 82 83 84 85 86 |
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 77 def batch_query_domain_stats(batch_query_domain_stats_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/domainStats:batchQuery', ) command.request_representation = Google::Apis::GmailpostmastertoolsV2::BatchQueryDomainStatsRequest::Representation command.request_object = batch_query_domain_stats_request_object command.response_representation = Google::Apis::GmailpostmastertoolsV2::BatchQueryDomainStatsResponse::Representation command.response_class = Google::Apis::GmailpostmastertoolsV2::BatchQueryDomainStatsResponse command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_domain(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::Domain
Retrieves detailed information about a domain registered by you. Returns NOT_FOUND if the domain is not registered by you. Domain represents the metadata of a domain that has been registered within the system and linked to a user.
113 114 115 116 117 118 119 120 121 |
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 113 def get_domain(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}', ) command.response_representation = Google::Apis::GmailpostmastertoolsV2::Domain::Representation command.response_class = Google::Apis::GmailpostmastertoolsV2::Domain command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_domain_compliance_status(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::DomainComplianceStatus
Retrieves the compliance status for a given domain. Returns PERMISSION_DENIED if you don't have permission to access compliance status for the domain.
145 146 147 148 149 150 151 152 153 |
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 145 def get_domain_compliance_status(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}', ) command.response_representation = Google::Apis::GmailpostmastertoolsV2::DomainComplianceStatus::Representation command.response_class = Google::Apis::GmailpostmastertoolsV2::DomainComplianceStatus command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_domains(page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::ListDomainsResponse
Retrieves a list of all domains registered by you, along with their corresponding metadata. The order of domains in the response is unspecified and non-deterministic. Newly registered domains will not necessarily be added to the end of this list.
183 184 185 186 187 188 189 190 191 192 |
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 183 def list_domains(page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/domains', ) command.response_representation = Google::Apis::GmailpostmastertoolsV2::ListDomainsResponse::Representation command.response_class = Google::Apis::GmailpostmastertoolsV2::ListDomainsResponse command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#query_domain_stats(parent, query_domain_stats_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GmailpostmastertoolsV2::QueryDomainStatsResponse
Retrieves a list of domain statistics for a given domain and time period. Returns statistics only for dates where data is available. Returns PERMISSION_DENIED if you don't have permission to access DomainStats for the domain.
219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/google/apis/gmailpostmastertools_v2/service.rb', line 219 def query_domain_stats(parent, query_domain_stats_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+parent}/domainStats:query', ) command.request_representation = Google::Apis::GmailpostmastertoolsV2::QueryDomainStatsRequest::Representation command.request_object = query_domain_stats_request_object command.response_representation = Google::Apis::GmailpostmastertoolsV2::QueryDomainStatsResponse::Representation command.response_class = Google::Apis::GmailpostmastertoolsV2::QueryDomainStatsResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |