Class: Google::Apis::GmailpostmastertoolsV2::QueryDomainStatsRequest
- Inherits:
-
Object
- Object
- Google::Apis::GmailpostmastertoolsV2::QueryDomainStatsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gmailpostmastertools_v2/classes.rb,
lib/google/apis/gmailpostmastertools_v2/representations.rb,
lib/google/apis/gmailpostmastertools_v2/representations.rb
Overview
Request message for QueryDomainStats.
Instance Attribute Summary collapse
-
#aggregation_granularity ⇒ String
Optional.
-
#metric_definitions ⇒ Array<Google::Apis::GmailpostmastertoolsV2::MetricDefinition>
Required.
-
#page_size ⇒ Fixnum
Optional.
-
#page_token ⇒ String
Optional.
-
#parent ⇒ String
Required.
-
#time_query ⇒ Google::Apis::GmailpostmastertoolsV2::TimeQuery
The date ranges or specific dates for which you want to retrieve data.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueryDomainStatsRequest
constructor
A new instance of QueryDomainStatsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueryDomainStatsRequest
Returns a new instance of QueryDomainStatsRequest.
756 757 758 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 756 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aggregation_granularity ⇒ String
Optional. The granularity at which to aggregate the statistics. If unspecified,
defaults to DAILY.
Corresponds to the JSON property aggregationGranularity
722 723 724 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 722 def aggregation_granularity @aggregation_granularity end |
#metric_definitions ⇒ Array<Google::Apis::GmailpostmastertoolsV2::MetricDefinition>
Required. The specific metrics to query. You can define a custom name for each
metric, which will be used in the response.
Corresponds to the JSON property metricDefinitions
728 729 730 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 728 def metric_definitions @metric_definitions end |
#page_size ⇒ Fixnum
Optional. The maximum number of DomainStats resources to return in the
response. The server may return fewer than this value. If unspecified, a
default value of 10 will be used. The maximum value is 200.
Corresponds to the JSON property pageSize
735 736 737 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 735 def page_size @page_size end |
#page_token ⇒ String
Optional. The next_page_token value returned from a previous List request, if
any. If the aggregation granularity is DAILY, the page token will be the
encoded date + "/" + metric name. If the aggregation granularity is OVERALL,
the page token will be the encoded metric name.
Corresponds to the JSON property pageToken
743 744 745 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 743 def page_token @page_token end |
#parent ⇒ String
Required. The parent resource name where the stats are queried. Format:
domains/domain
Corresponds to the JSON property parent
749 750 751 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 749 def parent @parent end |
#time_query ⇒ Google::Apis::GmailpostmastertoolsV2::TimeQuery
The date ranges or specific dates for which you want to retrieve data.
Corresponds to the JSON property timeQuery
754 755 756 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 754 def time_query @time_query end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
761 762 763 764 765 766 767 768 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 761 def update!(**args) @aggregation_granularity = args[:aggregation_granularity] if args.key?(:aggregation_granularity) @metric_definitions = args[:metric_definitions] if args.key?(:metric_definitions) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) @parent = args[:parent] if args.key?(:parent) @time_query = args[:time_query] if args.key?(:time_query) end |