Class: Google::Apis::GmailpostmastertoolsV2::QueryDomainStatsResponse
- Inherits:
-
Object
- Object
- Google::Apis::GmailpostmastertoolsV2::QueryDomainStatsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gmailpostmastertools_v2/classes.rb,
lib/google/apis/gmailpostmastertools_v2/representations.rb,
lib/google/apis/gmailpostmastertools_v2/representations.rb
Overview
Response message for QueryDomainStats.
Instance Attribute Summary collapse
-
#domain_stats ⇒ Array<Google::Apis::GmailpostmastertoolsV2::DomainStat>
The list of domain statistics.
-
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more results in the list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueryDomainStatsResponse
constructor
A new instance of QueryDomainStatsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueryDomainStatsResponse
Returns a new instance of QueryDomainStatsResponse.
631 632 633 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 631 def initialize(**args) update!(**args) end |
Instance Attribute Details
#domain_stats ⇒ Array<Google::Apis::GmailpostmastertoolsV2::DomainStat>
The list of domain statistics. Each DomainStat object contains the value for a
metric requested in the QueryDomainStatsRequest.
Corresponds to the JSON property domainStats
623 624 625 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 623 def domain_stats @domain_stats end |
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more
results in the list.
Corresponds to the JSON property nextPageToken
629 630 631 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 629 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
636 637 638 639 |
# File 'lib/google/apis/gmailpostmastertools_v2/classes.rb', line 636 def update!(**args) @domain_stats = args[:domain_stats] if args.key?(:domain_stats) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |